<?php
/**
 * @link              https://www.evergreencontentposter.com/
 * @since             1.0.0
 * @package           Evergreen_Content_Poster
 *
 * @wordpress-plugin
 * Plugin Name:       Evergreen Content Poster
 * Plugin URI:        https://www.evergreencontentposter.com/?utm_source=plugin%20description&utm_medium=software&utm_campaign=evergreen%20content%20poster
 * Description:       Automatically share your best WordPress content (posts/pages/custom post types) to X (Twitter), Mastodon, Facebook, Instagram, Pinterest, LinkedIn and Google Business Profiles. Keep your content alive and attract more visitors to your website! For questions, comments, or feature requests, <a href="https://www.evergreencontentposter.com/contact-us/?utm_source=plugin%20description&utm_medium=software&utm_campaign=Evergreen%20Content%20Poster">contact</a> us!
 * Version:           1.4.2
 * Author:            Evergreen Content Poster
 * Author URI:        https://www.evergreencontentposter.com/?utm_source=plugin%20description&utm_medium=software&utm_campaign=evergreen%20content%20poster
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       evergreen-content-poster
 * Domain Path:       /languages/
 */

// If this file is called directly, abort.
if (! defined('WPINC')) {
    die;
}

/**
 * Workaround to check and fix an error related to cookies when activating
 * the plugin using "Network Activate" plugin in a WordPress multisite environment
 *
 * @since    1.3.2
 */

if (is_ssl()) {
    if (!defined('SECURE_AUTH_COOKIE')) {
        define('SECURE_AUTH_COOKIE', 'wordpress_sec_' . md5(get_site_option('siteurl')));
    }
} else {
    if (!defined('AUTH_COOKIE')) {
        define('AUTH_COOKIE', 'wordpress_' . md5(get_site_option('siteurl')));
    }
}

//=============================================
// Define Constants
//=============================================
if (!defined('ABSPATH')) {
    exit;
}

require_once(ABSPATH.'wp-includes/pluggable.php');

if (!defined('EVERGREEN_CONTENT_POSTER_PLUGIN_NAME')) {
    define('EVERGREEN_CONTENT_POSTER_PLUGIN_NAME', 'Evergreen Content Poster');
}

if (!defined('EVERGREEN_CONTENT_POSTER_PATH')) {
    define('EVERGREEN_CONTENT_POSTER_PATH', untrailingslashit(plugins_url('', __FILE__)));
}

if (!defined('EVERGREEN_CONTENT_POSTER_PLUGIN_DIR')) {
    define('EVERGREEN_CONTENT_POSTER_PLUGIN_DIR', untrailingslashit(dirname(__FILE__)));
}

if (!defined('EVERGREEN_CONTENT_POSTER_PLUGIN_SLUG')) {
    define('EVERGREEN_CONTENT_POSTER_PLUGIN_SLUG', basename(dirname(__FILE__)));
}

if (!defined('EVERGREEN_CONTENT_POSTER_DB_VERSION')) {
    define('EVERGREEN_CONTENT_POSTER_DB_VERSION', '0.0.4');
}

if (!defined('EVERGREEN_CONTENT_POSTER_PLUGIN_VERSION')) {
    define('EVERGREEN_CONTENT_POSTER_PLUGIN_VERSION', '1.4.2');
}

if (!defined('EVERGREEN_CONTENT_POSTER_ENABLE_DEBUG')) {
    define('EVERGREEN_CONTENT_POSTER_ENABLE_DEBUG', false);
}

if (!defined('EVERGREEN_CONTENT_POSTER_KEY_PREFIX')) {
    define('EVERGREEN_CONTENT_POSTER_KEY_PREFIX', 'ecp');
}

if (EVERGREEN_CONTENT_POSTER_ENABLE_DEBUG) {
    error_reporting(E_ALL);
    ini_set('display_errors', 1);
}

//=============================================
// Network post length variables
//=============================================
if (!defined('EVERGREEN_CONTENT_POSTER_FACEBOOK_POST_LENGTH')) {
    define('EVERGREEN_CONTENT_POSTER_FACEBOOK_POST_LENGTH', '63206');
}

if (!defined('EVERGREEN_CONTENT_POSTER_FACEBOOK_GROUP_POST_LENGTH')) {
    define('EVERGREEN_CONTENT_POSTER_FACEBOOK_GROUP_POST_LENGTH', '63206');
}

if (!defined('EVERGREEN_CONTENT_POSTER_INSTAGRAM_POST_LENGTH')) {
    define('EVERGREEN_CONTENT_POSTER_INSTAGRAM_POST_LENGTH', '2200');
}

if (!defined('EVERGREEN_CONTENT_POSTER_LINKEDIN_PROFILE_POST_LENGTH')) {
    define('EVERGREEN_CONTENT_POSTER_LINKEDIN_PROFILE_POST_LENGTH', '1300');
}

if (!defined('EVERGREEN_CONTENT_POSTER_LINKEDIN_PAGE_POST_LENGTH')) {
    define('EVERGREEN_CONTENT_POSTER_LINKEDIN_PAGE_POST_LENGTH', '1300');
}

if (!defined('EVERGREEN_CONTENT_POSTER_PINTEREST_POST_LENGTH')) {
    define('EVERGREEN_CONTENT_POSTER_PINTEREST_POST_LENGTH', '500');
}

if (!defined('EVERGREEN_CONTENT_POSTER_TWITTER_POST_LENGTH')) {
    define('EVERGREEN_CONTENT_POSTER_TWITTER_POST_LENGTH', '280');
}

if (!defined('EVERGREEN_CONTENT_POSTER_GOOGLE_BUSINESS_PROFILE_POST_LENGTH')) {
    define('EVERGREEN_CONTENT_POSTER_GOOGLE_BUSINESS_PROFILE_POST_LENGTH', '1500');
}

if (!defined('EVERGREEN_CONTENT_POSTER_TIK_TOK_POST_LENGTH')) {
    define('EVERGREEN_CONTENT_POSTER_TIK_TOK_POST_LENGTH', '150');
}

if (!defined('EVERGREEN_CONTENT_POSTER_MASTODON_POST_LENGTH')) {
    define('EVERGREEN_CONTENT_POSTER_MASTODON_POST_LENGTH', '500');
}

// Twitter length is always 280 minus 24 charachters (fixed length for a URL + one space)
if (!defined('EVERGREEN_CONTENT_POSTER_TWITTER_POST_LENGTH_POST')) {
    define('EVERGREEN_CONTENT_POSTER_TWITTER_POST_LENGTH_POST', '256');
}
//=============================================
// Load Translation files
//=============================================

load_plugin_textdomain('evergreen-content-poster', false, dirname(plugin_basename(__FILE__)) . '/languages/');

//=============================================
// Hooks & Filters
//=============================================
/**
 * The class and function(s) used when activating the plugin, and redirecting the user after plugin activation.
 */
require_once plugin_dir_path(__FILE__) . 'includes/class-evergreen_content_poster-activator.php';

// function activate_evergreen_content_poster() @ class-evergreen_content_poster-activator.php

/**
 * The class and function(s) used when deactivating/uninstalling the plugin
 */
require_once plugin_dir_path(__FILE__) . 'includes/class-evergreen_content_poster-deactivator.php';

register_activation_hook(__FILE__, 'activate_evergreen_content_poster');
register_deactivation_hook(__FILE__, 'deactivate_evergreen_content_poster');
register_uninstall_hook(__FILE__, 'uninstall_evergreen_content_poster');

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path(__FILE__) . 'includes/class-evergreen_content_poster.php';
require plugin_dir_path(__FILE__) . 'includes/class-evergreen_content_poster-log.php';
require plugin_dir_path(__FILE__) . 'includes/class-evergreen_content_poster-cron_scheduler.php';

function wp_evergreen_content_schedule_cron($profile_id = null): void
{
    $set = new Evergreen_Content_Poster_Settings(new Evergreen_Content_Poster_Buffer(), new Evergreen_Content_Poster_Common());

    $set->ajaxPostBufferData($profile_id);
}
$general_settings = get_option('ecp_general_settings');
if (isset($general_settings['ecp_posting_schedule'])) {
    if ($general_settings['ecp_posting_schedule'] !== 'daily_posts') {
        add_action('wp_evergreen_content_schedule_cron_hook', 'wp_evergreen_content_schedule_cron');
    } else {
        foreach ($general_settings as $key => $value) {
            if (stripos($key, 'post_per_day_') !== false) {
                if ($value > 0) {
                    $profile_id = str_replace('post_per_day_', '', $key);
                    add_action($profile_id . '_wp_evergreen_content_schedule_cron_hook', function () use ($profile_id): void {
                        wp_evergreen_content_schedule_cron($profile_id);
                    });
                }
            }
        }
    }
}

add_action('admin_init', 'ecp_plugin_settings_redirect');
function non_ecp_posts_admin_notice(): void
{
    global $wpdb, $post;
    $screen = get_current_screen();

    //If not on the screen with ID 'edit-post' abort.
    if ($screen->base !== 'post' || $screen->parent_base !== 'edit' || !isset($_REQUEST['action']) || $_REQUEST['action'] !== 'edit') {
        return;
    } else {
        // Check ecp-post in wp-post
        $sql = $wpdb->prepare("SELECT meta_id FROM {$wpdb->prefix}postmeta WHERE meta_key = %s AND meta_value = %d", 'ecp-post-ref', $post->ID);
        $results = $wpdb->get_results($sql);
        if (count($results) === 0) {
            echo '<div class="notice notice-warning is-dismissible"><p>';
            echo sprintf(
            	/* translators: %1$s is a link start tag on this page, %2$s is the link closing tag */
                esc_html__('It looks like you did not create any evergreen social post yet for this piece of content. If you want you can easily do this right now by clicking %1shere%2s.', 'evergreen-content-poster'),
                '<a class="scroll_to_ecp_box" href="#" target="_blank">',
                '</a>'
            );
            echo '</p></div>';
        }
    }
}
add_action('admin_notices', 'non_ecp_posts_admin_notice');

/**
 * Check if the DB version is older than the current one installed,
 * and run update scripts if needed
 */
if (is_admin()) {
    $schedules_setting = get_option('ecp_schedule_settings');
    $schedules = [];
    if (!empty($schedules_setting)) {
        $schedules = $schedules_setting['schedules'] ?? [];
    }
    $options = get_option('ecp_options');

    if (isset($options['ecp_db_version'])) {
        if (version_compare($options['ecp_db_version'], EVERGREEN_CONTENT_POSTER_DB_VERSION) < 0) {
            // update db
            global $wpdb;
            $wpdb->evergreen_categories = $wpdb->prefix . 'evergreen_categories';

            require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
            if ($options['ecp_db_version'] === '0.0.1') {
                $charset_collate = $wpdb->get_charset_collate();

                $sql = "CREATE TABLE IF NOT EXISTS {$wpdb->evergreen_categories} (
              `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
              `name` varchar(191) NOT NULL DEFAULT '',
              `description` text,
              `status` int(1) NOT NULL DEFAULT 1,
              `is_default` int(1) DEFAULT NULL,
              `created_at` datetime DEFAULT NULL,
              `updated_at` datetime DEFAULT NULL,
              PRIMARY KEY (`id`)
            ) {$charset_collate};";

                dbDelta($sql);

                // Check categories
                $categories = $wpdb->get_results("SELECT * FROM {$wpdb->evergreen_categories}");
                if (empty((array) $categories)) {
                    // add default Category
                    $dateNow = date('Y-m-d H:i:s');
                    $insertSql = "INSERT INTO {$wpdb->evergreen_categories} (name, description, status, is_default, created_at, updated_at) VALUES ('default', '', 1, 1, '${dateNow}', null)";
                    dbDelta($insertSql);
                }

                $defaultCategory = $wpdb->get_row("SELECT * FROM {$wpdb->evergreen_categories} WHERE is_default = 1");

                // update category_id to schedule setting

                if (!empty($schedules)) {
                    foreach ($schedules as $service => $schedule) {
                        foreach ($schedule as $profileId => $singleSchedule) {
                            foreach ($singleSchedule as $k => $value) {
                                if (!empty($value->times)) {
                                    $times = [];
                                    foreach ($value->times as $time) {
                                        if (!is_array($time)) {
                                            $temp = [];
                                            $temp['time_push'] = $time;
                                            $temp['category_id'] = $defaultCategory->id;
                                            $times[] = $temp;
                                        }
                                    }

                                    $schedules[$service][$profileId][$k]->times = $times;
                                }
                            }
                        }
                    }
                }

                $schedules_setting['schedules'] = $schedules;
                update_option('ecp_schedule_settings', $schedules_setting, true);

                // get all ecp-posts in wp_post
                $ecp_saved_posts = $wpdb->get_results("SELECT * FROM {$wpdb->prefix}posts WHERE post_type = 'ecp-posts'");
                foreach ($ecp_saved_posts as $ecp_saved_post) {
                    // add category to post_meta
                    $itemSql = "INSERT INTO {$wpdb->prefix}postmeta (post_id, meta_key, meta_value) VALUES ({$ecp_saved_post->ID}, 'ecp-post-category', 1)";

                    dbDelta($itemSql);

                    delete_option('evergreen_content_date_last_active');
                    delete_option('evergreen_content_date_last_timestamp');
                }
            } elseif ($options['ecp_db_version'] === '0.0.2') {
                $alterSql = "ALTER TABLE {$wpdb->prefix}evergreen_content_logs MODIFY COLUMN action enum('publish','update','repost','bulk_publish', 'share', 'add_queue')";
                $wpdb->query($alterSql);
            } elseif ($options['ecp_db_version'] === '0.0.3') {
                // Update wp_evergreen_categories
                $sql = "SELECT * FROM {$wpdb->prefix}evergreen_categories WHERE is_default = 1";
                $defaultCategory = $wpdb->get_row($sql);
                if (!$defaultCategory) {
                    $dateNow = date('Y-m-d H:i:s');
                    $insertSql = "INSERT INTO {$wpdb->evergreen_categories} (name, description, random_availability, status, is_default, created_at, updated_at) VALUES ('Your evergreen content', 'Use this category to promote your own content - share any blog posts or pages you publish.', 1, 1, 1, '${dateNow}', null), ('Promotional', 'Use this category to promote your services/products. Make sure to include Calls To Actions (CTAs) like \"Book a call with us\" or \"start a trial account\".', 1, 1, 0, '${dateNow}', null), ('Quotes, Questions, and Fun', 'Use this category to generate engagement on your socials. Share inspirational or fun quotes, from your niche or create open questions for your audience.', 1, 1, 0, '${dateNow}', null)";
                    dbDelta($insertSql);
                } else {
                    if ($defaultCategory->name !== 'Your evergreen content') {
                        $alterSql = "ALTER TABLE {$wpdb->prefix}evergreen_categories ADD `random_availability` int(1) NOT NULL DEFAULT 1";
                        $wpdb->query($alterSql);
                        $wpdb->update($wpdb->prefix . 'evergreen_categories', ['name' => 'Your evergreen content', 'description' => 'Use this category to promote your own content - share any blog posts or pages you publish.'], ['id' => $defaultCategory->id]);
                        $dateNow = date('Y-m-d H:i:s');
                        $insertSql = "INSERT INTO {$wpdb->evergreen_categories} (name, description, random_availability, status, is_default, created_at, updated_at) VALUES ('Promotional', 'Use this category to promote your services/products. Make sure to include Calls To Actions (CTAs) like \"Book a call with us\" or \"start a trial account\".', 1, 1, 0, '${dateNow}', null), ('Quotes, Questions, and Fun', 'Use this category to generate engagement on your socials. Share inspirational or fun quotes, from your niche or create open questions for your audience.', 1, 1, 0, '${dateNow}', null)";
                        dbDelta($insertSql);
                    }
                }

                // Update DB frequency
                if (!get_option('ecp_frequency_schedules')) {
                    add_option('ecp_frequency_schedules', ['custom' => $schedules]);

                    $options['ecp_frequency'] = 'custom';
                }
            }

            $options['ecp_db_version'] = EVERGREEN_CONTENT_POSTER_DB_VERSION;

            update_option('ecp_options', $options);
        }
    }
    if (isset($options['ecp_version'])) {
        if (version_compare($options['ecp_version'], EVERGREEN_CONTENT_POSTER_PLUGIN_VERSION) < 0) {
            $general_settings = get_option('ecp_general_settings');
            if (isset($general_settings['ecp_posting_schedule'])) {
                if ($general_settings['ecp_posting_schedule'] === 'timestamp') {
                    $ecp_schedule_option = 3;
                } elseif ($general_settings['ecp_posting_schedule'] === 'empty_queue') {
                    $ecp_schedule_option = 2;
                } else {
                    $ecp_schedule_option = 1;
                }
            } else {
                $ecp_schedule_option = 1;
            }

            // update statistic api
            $token = evergreenGetStatisticsToken();
            $data['sites'] = [
                'url' => home_url(),
                'token' => $token,
                'ecp_schedule_option' => $ecp_schedule_option,
            ];

            updateApiStatistics($data);

            $options['ecp_version'] = EVERGREEN_CONTENT_POSTER_PLUGIN_VERSION;

            update_option('ecp_options', $options);
        }
    }
}

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_evergreen_content_poster(): void
{
    $plugin = new Evergreen_Content_Poster();
    $plugin->run();
}
run_evergreen_content_poster();

$setting = get_option('ecp_general_settings');
$e = new Evergreen_Content_Poster_Cron_Scheduler();

/**
 * Check and gen token
 *
 * @param $input
 */
function evergreenGetStatisticsToken($update_option = true)
{
    $options = get_option('ecp_options');
    /* Pos1 checks if "statusCode" exists in the variable $options['ecp_api_token'] or not
     * If it exists, it returns the position of that string
    */
    if (isset($options['ecp_api_token']) && $options['ecp_api_token'] && is_string($options['ecp_api_token'])) {
        $pos1 = strpos(json_encode($options['ecp_api_token']), "statusCode");
        if ($pos1 === false) {
            return $options['ecp_api_token'];
        }
    }

    $input['url'] = home_url();
    $folder = ABSPATH . 'wp-content/plugins/evergreen-content-poster/';

    $input['install_date'] = filectime($folder) ? date('Y-m-d H:i:s', filectime($folder)) : '';
    $input['activation_date'] = date('Y-m-d H:i:s');
    $input['status'] = 'activated';
    $input['version'] = EVERGREEN_CONTENT_POSTER_PLUGIN_VERSION;
    $input['plugin_name'] = 'evergreen content poster';
    $curl = curl_init();
    $options_curl = [
        CURLOPT_RETURNTRANSFER => 1,
        CURLOPT_URL => 'https://api.evergreencontentposter.com/auth',
        CURLOPT_POST => true,
        CURLOPT_USERAGENT => 'Mozilla/4.0 (compatible; MSIE 5.01; Windows NT 5.0)',
        CURLOPT_POSTFIELDS => $input,
    ];
    curl_setopt_array($curl, $options_curl);

    $curlResponse = curl_exec($curl);

    curl_close($curl);

    $pos = strpos(json_encode($curlResponse), "statusCode");
    if ($update_option && $pos === false) {
        $options['ecp_api_token'] = $curlResponse;

        update_option('ecp_options', $options);
    }

    return $curlResponse;
}

function updateApiStatistics($input): void
{
    $curl = curl_init();
    $options = [
        CURLOPT_RETURNTRANSFER => 1,
        CURLOPT_URL => 'https://api.evergreencontentposter.com/update',
        CURLOPT_POST => true,
        CURLOPT_USERAGENT => 'Mozilla/4.0 (compatible; MSIE 5.01; Windows NT 5.0)',
        CURLOPT_POSTFIELDS => ['value' => json_encode($input)],
    ];
    curl_setopt_array($curl, $options);

    $curlResponse = curl_exec($curl);
    curl_close($curl);
}

/**
 * Renders the Evergreen Content Poster Deactivation Survey Form.
 * Note: only for internal use
 *
 * @since 1.2.0
 */
function ecp_deactivation_popup(): void
{
    // Bailout.
    if (! current_user_can('delete_plugins')) {
        wp_die();
    }

    $a = is_network_admin();
    $results = [];

    // Start output buffering.
    ob_start(); ?>
        <div class="ecp-deactivate-popup">
            <div class="ecp-overlay-deactivate"></div>
            <div tabindex="-1" role="dialog" aria-labelledby="exampleModalLabel" aria-hidden="true" id="ecp-deactivate-modal">
                <div class="modal-dialog" role="document">
                    <div class="modal-content">
                        <div class="ecp-deactivation-survey-wrap">
                            <div class="ecp-modal-body">
                                <h2 id="ecp-deactivation-survey-title">
                                    <img src="<?php echo esc_url(EVERGREEN_CONTENT_POSTER_PATH); ?>/admin/img/ecp-icon.svg">
                                    <span><?php esc_html_e('Evergreen Content Poster Deactivation', 'evergreen-content-poster'); ?></span>
                                </h2>
                                <form class="ecp-deactivation-survey-form" method="POST">
                                    <p><?php esc_html_e('If you have a moment, please let us know why you are deactivating the Evergreen Content Poster. All submissions are anonymous and we only use this feedback to improve this plugin.', 'evergreen-content-poster'); ?></p>

                                    <div class="ecp-option">
                                        <label class="ecp-survey-field-description">
                                            <input type="radio" name="ecp-survey-radios" value="1">
                                            <?php esc_html_e('I\'m only deactivating temporarily', 'evergreen-content-poster'); ?>
                                        </label>
                                    </div>

                                    <div class="ecp-option">
                                        <label class="ecp-survey-field-description">
                                            <input type="radio" name="ecp-survey-radios" value="2">
                                            <?php esc_html_e('I no longer need the plugin', 'evergreen-content-poster'); ?>
                                        </label>
                                    </div>

                                    <div class="ecp-option">
                                        <label class="ecp-survey-field-description">
                                            <input type="radio" name="ecp-survey-radios" value="3" data-has-field="true">
                                            <?php esc_html_e('I found a better plugin', 'evergreen-content-poster'); ?>
                                        </label>

                                        <div class="ecp-survey-extra-field">
                                            <p><?php esc_html_e('What is the name of the plugin?', 'evergreen-content-poster'); ?></p>
                                            <input type="text" name="ecp-user-reason" class="widefat">
                                        </div>
                                    </div>

                                    <div class="ecp-option">
                                        <label class="ecp-survey-field-description">
                                            <input type="radio" name="ecp-survey-radios" value="4">
                                            <?php esc_html_e('I only needed the plugin for a short period', 'evergreen-content-poster'); ?>
                                        </label>
                                    </div>

                                    <div class="ecp-option">
                                        <label class="ecp-survey-field-description">
                                            <input type="radio" name="ecp-survey-radios" value="5" data-has-field="true">
                                            <?php esc_html_e('The plugin broke my site', 'evergreen-content-poster'); ?>
                                        </label>

                                        <div class="ecp-survey-extra-field">
                                            <p>
                                            <?php echo sprintf(
                                                /* translators: %1s is a link start tag to the WordPress support forums, %2s is the link closing tag. */
                                                    esc_html__('We\'re sorry to hear that, check %1sEvergreen Content Poster Support%2s. Can you describe the issue?', 'evergreen-content-poster'),
                                                    '<a href="https://wordpress.org/support/plugin/evergreen-content-poster">',
                                                    '</a>'
                                                ); ?>
                                            </p>
                                            <textarea disabled name="ecp-user-reason" class="widefat" rows="6"></textarea>
                                        </div>
                                    </div>

                                    <div class="ecp-option">
                                        <label class="ecp-survey-field-description">
                                            <input type="radio" name="ecp-survey-radios" value="6" data-has-field="true">
                                            <?php esc_html_e('The plugin suddenly stopped working', 'evergreen-content-poster'); ?>
                                        </label>

                                        <div class="ecp-survey-extra-field">
                                            <p>
	                                            <?php echo sprintf(
                                                    /* translators: %1s is a link start tag to the WordPress support forums, %2s is the link closing tag. */
                                                        esc_html__('We\'re sorry to hear that, check %1sEvergreen Content Poster Support%2s. Can you describe the issue?', 'evergreen-content-poster'),
                                                        '<a href="https://wordpress.org/support/plugin/evergreen-content-poster">',
                                                        '</a>'
                                                    ); ?>
                                            </p>
                                            <textarea disabled name="ecp-user-reason" class="widefat" rows="6"></textarea>
                                        </div>
                                    </div>
                                    <?php
                                        $buffer = new Evergreen_Content_Poster_Buffer();
                                        if(!$buffer->get_token()) {
                                    ?>
                                        <div class="ecp-option">
                                            <label class="ecp-survey-field-description">
                                                <input type="radio" name="ecp-survey-radios" value="8" data-has-field="true">
                                                <?php esc_html_e('I don\'t have a Buffer account', 'evergreen-content-poster'); ?>
                                            </label>

                                            <div class="ecp-survey-extra-field">
                                                <p><?php esc_html_e('Please let us know which social network you would like us to integrate directly', 'evergreen-content-poster'); ?></p>
                                                 <input type="text" name="ecp-user-reason" class="widefat">
                                            </div>
                                        </div>
                                    <?php
                                        } ?>

                                    <div class="ecp-option">
                                        <label class="ecp-survey-field-description">
                                            <input type="radio" name="ecp-survey-radios" value="7" data-has-field="true">
                                            <?php esc_html_e('Other', 'evergreen-content-poster'); ?>
                                        </label>

                                        <div class="ecp-survey-extra-field">
                                            <p><?php esc_html_e('Please describe why you\'re deactivating the Evergreen Content Poster', 'evergreen-content-poster'); ?></p>
                                            <textarea disabled name="ecp-user-reason" class="widefat" rows="6"></textarea>
                                        </div>
                                    </div>

                                    <div id="ecp-survey-and-delete-data">
                                        <p>
                                            <label>
                                                <input type="checkbox" name="ecp-confirm_reset_store" value="1">
                                                <?php esc_html_e('Would you like to delete all Evergreen Content Poster data?', 'evergreen-content-poster'); ?>
                                            </label>
                                        <section class="ecp-survey-field-description">
                                            <?php _e('By default your social media posting schedule, Evergreen Content Poster options, and evergreen content (your social media posts) are not deleted when you deactivate the Evergreen Content Poster. If you are deleting the Evergreen Content Poster completely from your website and want those items removed as well check this option.<br /><strong>Note: This will permanently delete all Evergreen Content Poster data from your database.</strong>', 'evergreen-content-poster'); ?>
                                        </section>
                                        </p>
                                    </div>
                                    <?php
                                    $current_user = wp_get_current_user();
                                    $current_user_email = $current_user->user_email; ?>
                                    <input type="hidden" name="ecp-current-user-email" value="<?php echo $current_user_email; ?>">
                                    <input type="hidden" name="ecp-current-site-url" value="<?php echo esc_url(get_bloginfo('url')); ?>">
                                    <?php wp_nonce_field('ecp_ajax_export', 'ecp_ajax_export'); ?>
                                </form>
                            </div>
                            <div class="ecp-modal-controls">

                                <div class="spinner"></div>
                                <a class="ecp-modal--additional-link" href=""><?php _e('Skip and Deactivate', 'evergreen-content-poster') ?></a>

                                <button class="btn btn-default ecp-cancel-deactive ecp-deactivate-but">
                                    <?php _e('Cancel', 'evergreen-content-poster') ?>
                                </button>

                                <button class="btn btn-primary ecp-submit-deactive ecp-deactivate-but" data-current-url="" data-url="">
                                    <?php _e('Submit and Deactivate', 'evergreen-content-poster') ?>
                                </button>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
<?php

    // Echo content (deactivation form) from the output buffer.
    $output = ob_get_clean();

    $results['html'] = $output;

    wp_send_json($results);
}

add_action('wp_ajax_ecp_deactivation_popup', 'ecp_deactivation_popup');

function ecp_deactivation_submit($network_wide): void
{
    global $wpdb;
    $value = absint($_POST['value']);
    $reason = sanitize_text_field($_POST['reason']);

    //Update API
    $token = evergreenGetStatisticsToken();

    $number_active_plugins = 0;
    if (get_option('active_plugins')) {
        $number_active_plugins = count(get_option('active_plugins'));
    }

    $general_settings = get_option('ecp_general_settings');
    if (isset($general_settings['ecp_posting_schedule'])) {
        if ($general_settings['ecp_posting_schedule'] === 'timestamp') {
            $ecp_schedule_option = 3;
        } elseif ($general_settings['ecp_posting_schedule'] === 'empty_queue') {
            $ecp_schedule_option = 2;
        } else {
            $ecp_schedule_option = 1;
        }
    } else {
        $ecp_schedule_option = 1;
    }

    $data['sites'] = [
        'url' => home_url(),
        'token' => $token,
        'deactivation_radio_value' => $value,
        'deactivation_date' => date('Y-m-d H:i:s'),
        'deactivation_reason' => $reason,
        'plugin_name' => 'evergreen content poster',
        'number_active_plugins' => $number_active_plugins,
        'ecp_schedule_option' => $ecp_schedule_option,
        'status' => 'deactivated',
    ];

    $bufferClass = new Evergreen_Content_Poster_Buffer();

    $profiles = $bufferClass->profiles();
    if (!empty($profiles)) {
        $text = 'Buffer was connected with the following social media profiles ';

        foreach ($profiles as $network => $profile) {
            foreach ($profile as $single_profile) {
                $text .= ucfirst($single_profile->service) . ' ' . ucfirst($single_profile->service_type) . ': ' . $single_profile->formatted_username . ' / ';
            }
        }
        $text = trim($text, ' / ');
    } else {
        $text = 'No social media networks were connected';
    }

    $data['sites']['buffer_text'] = $text;

    updateApiStatistics($data);

    // Delete all data
    if (absint($_POST['delete_all_data'])) {
//        add_action( 'deactivated_plugin', 'delete_all_option',10,2 );
        $current_url = $_POST['current_url'];
        if (strpos($current_url, '/network/')) {
            $network_wide = true;
        } else {
            $network_wide = false;
        }
        $deactivator = new Evergreen_Content_Poster_Deactivator();
        $deactivator->ecp_deactivate($network_wide);

        $deactivator->unregister_settings($network_wide);

        if (! is_multisite() || !$network_wide) {
            delete_all_option();
        } else {
            // Multisite network wide deactivation
            foreach (get_sites(['fields' => 'ids']) as $blog_id) {
                switch_to_blog($blog_id);
                delete_all_option();
                restore_current_blog();
            }
        }
    }

    wp_send_json_success([
        'error' => 200,
        'message' => 'OK',
    ]);
}

add_action('wp_ajax_ecp_deactivation_submit', 'ecp_deactivation_submit');

function delete_all_option(): void
{
    global $wpdb;
    // Delete all post meta
    $deleteSql = "DELETE FROM {$wpdb->prefix}postmeta WHERE post_id IN (SELECT ID FROM {$wpdb->prefix}posts WHERE post_type = 'ecp-posts')";

    $wpdb->query($deleteSql);

    // Delete all post
    $wpdb->query("DELETE FROM {$wpdb->prefix}posts WHERE post_type = 'ecp-posts'");

    // Delete all metadata
    delete_metadata('user', 0, 'ecp-getting-started-dismissed', '', true);
    delete_metadata('user', 0, 'ecp-wp-cron-notice-dismissed', '', true);
    delete_metadata('user', 0, 'ecp-wp-translate-notice-dismissed', '', true);
}

if (isset($_COOKIE['ecp-height']) && isset($_COOKIE['ecp-width']) && (!isset($_COOKIE['ecp-set-resolution']) || !$_COOKIE['ecp-set-resolution'])) {
    $token = evergreenGetStatisticsToken();

    $resolution = $_COOKIE['ecp-width'] . ' x ' . $_COOKIE['ecp-height'];
    $common = new Evergreen_Content_Poster_Common();

    $language = $common->ecp_get_user_locale();
    $data['sites'] = [
        'url' => home_url(),
        'token' => $token,
        'screen_resolution' => $resolution,
        'language' => $language,
    ];

    updateApiStatistics($data);
    setcookie('ecp-width', '', time() - 3600);
    setcookie('ecp-height', '', time() - 3600);
    if (!isset($_COOKIE['ecp-set-resolution'])) {
        setcookie('ecp-set-resolution', '1');
    }
}

add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'ecp_add_settings_links');
/**
 * Add a "Settings", "Content library", "Configuration wizard" link to the listing on the plugins page
 *
 * @since  1.3.1
 * @param  array $links Array of links passed in from WordPress core.
 * @return array $links Array of links modified by the function passed back to WordPress
 */

function ecp_add_settings_links($links)
{
    $settings_link = sprintf(
	    '<a href="admin.php?page=evergreen-content-settings">%s</a>',
	    esc_html__('Settings', 'evergreen-content-poster')
	);

    $library_link = sprintf(
	    '<a href="admin.php?page=evergreen-content-library">%s</a>',
	    esc_html__('Content library', 'evergreen-content-poster')
	);

    $configuration_link = sprintf(
	    '<a href="admin.php?page=evergreen-content-configurator">%s</a>',
	    esc_html__('Configure', 'evergreen-content-poster')
	);

    array_unshift($links, $settings_link, $library_link, $configuration_link);

    return $links;
}
