<?php
/**
 * The logging class.
 *
 * This is used to log the items pushed to the social networks into a logging table
 * for potential debugging and knowing when to do another push of your content
 *
 *
 * @link       https://www.evergreencontentposter.com/
 * @since      1.0.0
 * @package    Evergreen_Content_poster
 * @subpackage Evergreen_Content_Poster/includes
 * @author     evergreencontentposter <support@evergreencontentposter.com>
 */

class Evergreen_Content_Poster_Log
{
    /**
     * Holds the DB table name
     *
     * @since   1.0.0
     *
     * @var     string
     */
    private $table;

    /**
     * Holds items added to the debug log using add_to_debug_log(),
     *
     * @since   1.0.0
     *
     * @var     array
     */
    private $debug_log = [];

    /**
     * Constructor
     *
     * @since   3.0.0
     */
    public function __construct()
    {
        // Define the database table name
        $this->table = 'evergreen_content' . '_logs';
    }

    /**
     * Adds a log entry for the given Post ID
     *
     * @since   1.0.0
     *
     * @param   int     $post_id    Post ID
     * @param   array   $log        Log
     *      enum            $action             Action (publish,update,repost,bulk_publish)
     *      datetime        $request_sent       Request Sent to API
     *      string          $profile_id         Profile ID
     *      string          $profile_name       Profile Name
     *      enum            $result             Result (success,test_mode,pending,error)
     *      string          $result_message     Result Message
     *      string          $status_text        Status Text
     *      datetime        $status_created_at  Status Created At on API
     *      datetime        $status_due_at      Status Scheduled for Publication to Profile
     */
    public function add2log($post_id, $log): void
    {
        global $wpdb;

        // Enable error output if WP_DEBUG is enabled.
        $wpdb->show_errors();

        // Add Post ID to log
        $log['post_id'] = absint($post_id);

        // Insert Log
        $result = $wpdb->insert(
            $wpdb->prefix . $this->table,
            $log
        );
        $general_settings = get_option('ecp_general_settings');
            if( 'Y' === $general_settings['publish_notification'] && 'success' === $log['result'] ) {
                require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-evergreen_content_poster-notifier.php';
                $this->publisher_notifier = new Evergreen_Content_Poster_Template_Notifier();
                $this->publisher_notifier->prepare_email_body( $log );
            }
            if( 'Y' === $general_settings['publish_failure'] && 'error' === $log['result'] ) {
                require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-evergreen_content_poster-notifier.php';
                $this->failure_notifier = new Evergreen_Content_Poster_Template_Notifier();
                $this->failure_notifier->prepare_email_body( $log );
            }
    }
}
