<?php
/**
 * The notification class
 *
 * Sends emails to the user when activated in settings upon successful
 * publication or failure to publish a post to the user's social media account.
 *
 * @link       https://www.evergreencontentposter.com/
 * @since      1.3.6
 * @package    Evergreen_Content_Poster
 * @subpackage Evergreen_Content_Poster/includes
 * @author     evergreencontentposter <support@evergreencontentposter.com>
 */
class Evergreen_Content_Poster_Template_Notifier {

    /**
     * Class constructor
     */
    public function __construct(){}

     /**
     * Prepare the email body with dynamically variables.
     *
     * @param   array $getlogdata
     * @return  bool
     */
    public function prepare_email_body ( $getlogdata ) {
        $ecp_notification_info['profile_name'] = explode(':' , $getlogdata['profile_name']);
        if ( 'success' === $getlogdata['result'] ) {
            $subject = __('One of your updates has just been posted', 'evergreen-content-poster');
            $emailContainer = sprintf( __(' <div class="container">
                                <h1>&#127881; The Evergreen Content Poster just posted one of your updates.</h1>
                                <p>Hey &#128075; there,</p>
                                <p>Great news! The social media update for your %s(%s) account has successfully been shared at %s</p>
                                <p>This was the update:</p>
                                <p>%s</p>
                                <p>Have a great day!</p>
                                <p>Cheers,<br />Hans from the Evergreen Content Poster</p>
                            </div>', 'evergreen-content-poster'),
                            $ecp_notification_info['profile_name'][0],
                            $ecp_notification_info['profile_name'][1],
                            $getlogdata['request_sent'],
                            $getlogdata['status_text']);
            $this->send_email_notifier( $emailContainer, $subject);
        } else if ( 'error' === $getlogdata['result'] ) {
            $subject = __('A post failed to publish', 'evergreen-content-poster');
            $emailContainer = sprintf( __('<div class="container">
                                <h1>&#128542; The Evergreen Content Poster failed while trying to publish a post.</h1>
                                <p>Hey &#128075; there,</p>
                                <p>Whoops! We\'re so sorry that we weren\'t able to post your social media update for your %s account (%s).
                                </p>
                                <p>We tried to publish your post:</p>
                                <p>%s</p>
                                <p>at %s, but something went wrong.</p>
                                <p>Here\'s the error message:</p>
                                <p><i>%s</i></p>
                                <p>We\'re sorry that things didn\'t go as planned, but hope you still have a good day!</p>
                                <p>Cheers,<br />Hans from the Evergreen Content Poster</p>
                            </div>', 'evergreen-content-poster'),
                            $ecp_notification_info['profile_name'][0],
                            $ecp_notification_info['profile_name'][1],
                            $getlogdata['status_text'],
                            $getlogdata['request_sent'],
                            $getlogdata['result_message']);
            $this->send_email_notifier( $emailContainer, $subject);
        }
    }

    /**
     * Sends the email if the post is published/failed to post on social media.
     *
     * @param   string
     * @return  bool $emailContainer    Whether the email contents were sent successfully. A true return value does not automatically mean that the user received the email successfully. It just only means that the method used was able to process the request without any errors.
     */
    public function send_email_notifier ( $emailContainer, $subject ) {
        $general_settings = get_option('ecp_general_settings');
        $ecpTo = $general_settings['notification_emails'];
        $fromEmail = 'hans@evergreencontentposter.com';
        $headers = "From: " . $fromEmail . "\r\n";
        $headers.= "X-Mailer: PHP/" . phpversion() . "\r\n";
        $headers.= "MIME-Version: 1.0\r\n";
        $headers.= "Content-type: text/html; charset=utf-8\r\n";
        $ecpStyles = 'body{padding:0;margin:0;font-family:HelveticaNeueLight,HelveticaNeue-Light,"Helvetica NeueLight",HelveticaNeue,"Helvetica Neue",Helvetica,Arial,"Lucida Grande",sans-serif}.outer{width:100%;min-height:100%;background-color:#edf2f7;padding:25px 25px 50px;box-sizing:border-box}.wrapper{max-width:700px;margin:0 auto}h1,h2{color:#1d2531;font-weight:700;margin-top:25px}.bottom,.footer{text-align:center}h1{font-size:24px}h2{font-size:20px}a,p,ul{color:#718096;font-size:18px;line-height:1.4}hr{width:60%;border:1px solid #edf2f7;border-left:0;border-right:0;margin:50px auto}.img{width:100%;max-width:700px}.header-image{width:100%;max-width:275px;margin:0 auto;display:block}.view-in-browser-link{width:250px;text-align:center;display:block;margin:25px auto 0;color:#1972f5!important}.blog-box,.blog-box-mobile,.bottom,.container{width:100%;box-sizing:border-box}.blog-box{padding:25px 0;display:block}.blog-box-mobile{display:none;padding-top:25px}.blog-box-mobile div{margin-top:10px}.container{background-color:#fbfcfc;padding:25px;color:#333;border:1px solid #e3e3e3}.primary-button{color:#fff!important;font-weight:500;font-size:18px;line-height:18px;text-decoration:none;display:inline-block;border-radius:5px;background-color:#fb5654;padding:18px 30px;margin:10px auto}.bottom{height:50px;background-color:#fff;border:1px solid #e3e3e3;border-top:none}.bottom-link{color:#b0adc5!important;font-size:12px;line-height:48px;margin:0 10px}.footer,.greeting{width:100%;margin-top:25px}.footer{font-size:12px;color:#b0adc5}.greeting{max-width:300px}.greeting-image{width:75px;height:75px;border-radius:50%;border:4px solid #1972f5}@media screen and (max-width:600px){.outer{padding:0 0 50px}h1{font-size:20px}h2{font-size:18px}a,p,ul{font-size:16px;line-height:1.4}.primary-button{font-size:14px;line-height:15px;padding:12px 24px;margin:0 auto}.blog-box{display:none}.blog-box-mobile{display:block}}';
        $emailBody = '<!DOCTYPE html><html '.get_language_attributes().'><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /> <style> '. $ecpStyles .' </style></head>
                        <body>
                        <div class="outer">
                            <div class="wrapper">
                                <a href="https://www.evergreencontentposter.com/">
                                    <img class="header-image" src="https://imgur.com/xrGSbEi.png"/>
                                </a>
                                '. $emailContainer .'
                                <div class="bottom">
                                    <a class="bottom-link" href="https://www.evergreencontentposter.com/?utm_source=failed%20publication%20email&utm_medium=email&utm_campaign=evergreen%20content%20poster">'. __('Evergreen Content Poster Website', 'evergreen-content-poster').' </a>
                                    <a class="bottom-link" href="https://www.evergreencontentposter.com/support/?utm_source=failed%20publication%20email&utm_medium=email&utm_campaign=evergreen%20content%20poster">'. __('User Guides', 'evergreen-content-poster').'</a>
                                </div>

                                <div class="footer">'.sprintf( __('%s Evergreen Content Poster. All rights reserved.','evergreen-content-poster'), date("Y")).'</div>
                            </div>
                        </div>
                    </body>';
        $emailSent = wp_mail($ecpTo, $subject, $emailBody, $headers );

    }
}
