<?php
/**
 * The Native Twitter class.
 *
 * This class is used for handling all Buffer related functions.
 *
 * @link       https://www.evergreencontentposter.com/
 * @since      1.0.0
 * @package    Evergreen_Content_Poster
 * @subpackage Evergreen_Content_Poster/includes
 * @author     evergreencontentposter <support@evergreencontentposter.com>
 *
 *
 * $client_id = '';
 * $client_secret = '';
 * $callback_url = '';
 * $buffer = new BufferApp($client_id, $client_secret, $callback_url);
 */

class Evergreen_Content_Poster_Twitter {
     /**
     * The service OAuth URL
     */
    private $twitter_oauth_url;
    private $twitter_oauth_url_config;

    /**
     * The plugin option fields
     */
    private $twitterAccessToken = EVERGREEN_CONTENT_POSTER_KEY_PREFIX . '_twitter_token';
    private $twitterAccessProfiles = EVERGREEN_CONTENT_POSTER_KEY_PREFIX . '_twitter_profiles';
    private $option_schedule_settings = EVERGREEN_CONTENT_POSTER_KEY_PREFIX . '_schedule_settings';
    private $ecp_native_profiles = EVERGREEN_CONTENT_POSTER_KEY_PREFIX . '_native_profiles';

    public $responses = [
        '304' => 'Not Modified - There was no new data to return.',
        '400' => 'Bad Request - The request was invalid or cannot be otherwise served. An accompanying error message will explain further. Requests without authentication or with invalid query parameters are considered invalid and will yield this response.',
        '401' => 'Unauthorized - There was a problem authenticating your request. This could be due to missing or incorrect authentication credentials. This may also be returned in other undefined circumstances.',
        '403' => 'Forbidden - The request is understood, but it has been refused or access is not allowed. An accompanying error message will explain why.',
        '404' => 'Not Found - The URI requested is invalid or the resource requested, such as a user, does not exist.',
        '406' => 'Not Acceptable - Returned when an invalid format is specified in the request. Generally, this occurs where your client fails to properly include the headers to accept gzip encoding, but can occur in other circumstances as well.',
        '409' => 'Connection Exception - Returned when attempting to connect to a filtered stream that has no rules. ',
        '410' => 'Gone - This resource is gone. Used to indicate that an API endpoint has been turned off.',
        '422' => 'Unprocessable Entity - Returned when the data is unable to be processed.',
        '429' => 'Too Many Requests - Returned when a request cannot be served due to the App\'s rate limit or Tweet cap having been exhausted. See Rate Limiting.',
        '500' => 'Internal Server Error - Something is broken. This is usually a temporary error, for example in a high load situation or if an endpoint is temporarily having issues.',
        '502' => 'Bad Gateway - Twitter is down, or being upgraded',
        '503' => 'Service Unavailable - The Twitter servers are up, but overloaded with requests. Try again later.',
        '504' => 'Gateway Timeout - The Twitter servers are up, but the request couldn’t be serviced due to some failure within the internal stack. Try again later.',
    ];

    public function __construct() {

        // return the function if the call is not from the twitter button.
        if( ! isset($_GET['ecp-twitter-auth-token']) ) {
            return;
        }
        //fetch the connected buffer profiles.
        $bufferToken = get_option('ecp_buffer_profiles');
        $twitterAuthTokens = json_decode( $_GET['ecp-twitter-auth-token'], true);
        if( isset($bufferToken) && $bufferToken && $bufferToken !== 'null' ) {
            $ecpProfileChecked = $this->validate_the_profiles($bufferToken, $twitterAuthTokens);
            if( isset( $ecpProfileChecked ) && 'true' === $ecpProfileChecked ) {
                update_option('buffer-already-connected', $ecpProfileChecked );
                update_option('ecp-buffer-connected-profile', $twitterAuthTokens['screen_name'] );
                wp_safe_redirect(admin_url('admin.php?page=evergreen-content-settings'));
                return;
            }
        }
        $TwitterToken = get_option('ecp_twitter_token');
        if( ! $TwitterToken ) {
            $this->twitter_store_access_token($twitterAuthTokens);
        }
    }

    /**
     * Functions to validate profiles if they are already connected with the same account or not.
     */
    public function validate_the_profiles($bufferToken, $twitterUserId) {
        $twitterUserId = isset($twitterUserId['user_id']) ? $twitterUserId['user_id'] : '';
        $token = json_decode($bufferToken, true);
        if (is_array($token) || is_object($token)) {
        foreach($token as $key => $value ) {
            if('twitter' === $key ) {
                foreach($value as $keys => $twitterData) {
                        if( $twitterUserId === $twitterData['service_id'] ) {
                            return 'true';
                        }
                }
            }
        }
    }
       return 'false';
    }

    public function twitter_store_access_token($twitterAuthTokens) {

        // If the current logged-in user can't edit option values, abort
        if (! current_user_can('manage_options')) {
            return false;
        }

        if( isset($_GET['ecp-user']) && isset($_GET['ecp-twitter-nonce']) && isset($twitterAuthTokens) ) {
            $ecpUser = $_GET['ecp-user'];
            $ecpNonce = $_GET['ecp-twitter-nonce'];
            $ecpState = $_GET['ecp-state'];

            $ecpAccessToken[] = $twitterAuthTokens['oauth_token'];
            $ecpAccessToken[] = $twitterAuthTokens['oauth_token_secret'];
            $ecpAccessProfiles['native-twitter']['user_id'] = $twitterAuthTokens['user_id'];
            $ecpAccessProfiles['native-twitter']['screen_name'] = $twitterAuthTokens['screen_name'];
            $ecpAccessProfiles['native-twitter']['service'] = 'native-twitter';
            $ecpAccessProfiles['native-twitter']['schedules'] = $this->fetch_profiles();
            // Store the whole native proflies objects.
            $nativeTwitter['native-twitter'] = [
                '0' => (object) [
                    '_id' => $ecpAccessProfiles['native-twitter']['user_id'],
                    'avatar' => EVERGREEN_CONTENT_POSTER_PATH . '/admin/img/ecp-profile-unknown.png',
                    'formatted_service' => $ecpAccessProfiles['native-twitter']['service'],
                    'formatted_username' => $ecpAccessProfiles['native-twitter']['screen_name'],
                    'id' => $ecpAccessProfiles['native-twitter']['user_id'],
                    'schedules' => $ecpAccessProfiles['native-twitter']['schedules'],
                    'service' => 'native-twitter',
                    'service_id' => $ecpAccessProfiles['native-twitter']['user_id'],
                    'service_type' => 'profile',
                    'service_username' => $ecpAccessProfiles['native-twitter']['screen_name'],
                ],
            ];
            $nativeProfiles = (object) $nativeTwitter;
            update_option($this->twitterAccessToken, $ecpAccessToken);
            update_option($this->twitterAccessProfiles, $ecpAccessProfiles);
            update_option($this->ecp_native_profiles, $nativeProfiles);
            wp_safe_redirect($ecpState);
            exit();
        }
    }

    public function twitter_oauth_url() {
        $nonce = wp_create_nonce( 'ecp-twitter-nonce' );
        $ecpUserId = get_current_user_id();
        // Return oAuth URL
        return 'https://stagingapi.evergreencontentposter.com/twitter-auth?ecp-user='.esc_attr($ecpUserId).'&ecp-twitter-nonce=' . esc_attr( $nonce ) . '&response_type=code&state=' . urlencode(admin_url('admin.php?page=evergreen-content-settings'));
    }

    public function twitter_oauth_url_config() {
        $nonce = wp_create_nonce( 'ecp-twitter-nonce' );
        $ecpUserId = get_current_user_id();
        // Return oAuth URL
        return 'https://stagingapi.evergreencontentposter.com/twitter-auth?ecp-user='.esc_attr($ecpUserId).'&ecp-twitter-nonce=' . esc_attr( $nonce ) . '&response_type=code&state=' . urlencode(admin_url('admin.php?page=evergreen-content-configurator'));
    }


    /**
     * Public function to fetch the current stored Twitter Token
     * auth token from the WordPress wp_options table
     *
     * @since  1.0.0
     */
    public function get_token()
    {
        $token = get_option($this->twitterAccessToken);

        // "false" if token does not exist (plugin is deauthorized)
        // "null" if plugin is activated first time but no connection has been made yet to Buffer
        if (!$token || 'null' === $token) {
            return false;
        }
        return $token;
    }

    /**
     * Public function that triggers a series of actions
     * to deauthorize Buffer access in local install
     *
     * @since  1.0.0
     */
    public function deauthorize(): void
    {
        // first delete token
        $this->remove_token();       

        // then delete profiles
        $this->remove_profiles();
        //Updated the option into database
        update_option('buffer-already-connected', 'false' );
    }

    /**
     * Public function to remove the Twitter auth token from the
     * WordPress wp_options table
     *
     * @since  1.0.0
     */
    public function remove_token()
    {
        // if user can't edit option values, abort
        if (! current_user_can('manage_options')) {
            return false;
        }

        // delete_user_meta( $user_id, 'ecp_twitter_access_token' );
        delete_option($this->twitterAccessToken);
    }

    /**
     * Delete stored Twitter profiles
     */
    public function remove_profiles()
    {
        // if user can't edit option values, abort
        if (! current_user_can('manage_options')) {
        return false;
        }

        return delete_option($this->twitterAccessProfiles);
    }

    public function fetch_profiles()
    {
        $token = $this->get_token();

        if (is_null($token)) {
            return false;
        }

        $twitter_profile_ids = [];
        $profiles = [];
        $tokens = json_decode( $_GET['ecp-twitter-auth-token'], true);
        $tokensId = isset( $tokens['user_id'] ) ? $tokens['user_id'] : '';

        // save profile schedules to settings
        $schedules_setting = $this->schedules();
        $schedules = isset($schedules_setting['schedules']) ? $schedules_setting['schedules'] : [];
        $schedules_init = [];
        if (!isset($schedules['native-twitter'][$tokensId]) || empty($schedules['native-twitter'][$tokensId])) {
            $schedules_init = [
                '0' => (object) ['days' => ['sun'], 'times' => []],
                '1' => (object) ['days' => ['mon'], 'times' => []],
                '2' => (object) ['days' => ['tue'], 'times' => []],
                '3' => (object) ['days' => ['wed'], 'times' => []],
                '4' => (object) ['days' => ['thu'], 'times' => []],
                '5' => (object) ['days' => ['fri'], 'times' => []],
                '6' => (object) ['days' => ['sat'], 'times' => []]
            ];

            $schedules['native-twitter'][$tokensId] = $schedules_init;
        }

        $schedules_setting['schedules'] = $schedules;

        $this->save_schedules($schedules_setting);

        return $schedules_init;
    }

    public function profiles()
    {
        if (!$this->get_token()) {
            return [];
        }

        $refetch = false;

        if (empty($this->profiles)) {
            $refetch = true;
        }

        if (null === json_decode($this->profiles)) {
            $refetch = true;
        }

        if ($refetch) {
            $this->profiles = $this->fetch_profiles();
        }

        if (!$this->profiles) {
            return [];
        }

        return json_decode($this->profiles);
    }

    /**
     * Load existing Twitter profiles stored in options table
     */
    public function load_profiles()
    {
        return get_option($this->twitterAccessProfiles);
    }

    /**
     * Create deauthorize URL to disconnect Twitter
     */
    public function deauthorize_url($page)
    {
        return admin_url('admin.php?page=' . $page . '&action=disconnect_twitter');
    }

    // Sending request to the API server to Post the tweet.
    function post_tweet($input) {

        $curl = curl_init();
        $options = [
            CURLOPT_RETURNTRANSFER => 1,
            CURLOPT_URL => 'https://stagingapi.evergreencontentposter.com/post-tweet',
            CURLOPT_POST => true,
            CURLOPT_USERAGENT => 'Mozilla/4.0 (compatible; MSIE 5.01; Windows NT 5.0)',
            CURLOPT_POSTFIELDS => ['value' => json_encode($input)],
        ];
        curl_setopt_array($curl, $options);
        $curlResponse = curl_exec($curl);
        curl_close($curl);


        if( 'success' == $curlResponse ) {
            return $curlResponse;
        }
        else {
            return json_decode($curlResponse);
        }
    }

    /**
     * Load existing Buffer profile schedules stored in options table
     */
    public function load_schedules()
    {
        return get_option($this->option_schedule_settings);
    }

    /**
     * Delete stored Buffer profile schedules
     */
    public function remove_schedules()
    {
        return delete_option($this->option_schedule_settings);
    }

    /**
     * Fetch the schedules for the native twitter.
     */
    public function schedules()
    {
        $settings = get_option($this->option_schedule_settings);

        // "false" if token does not exist (plugin is deauthorized)
        // "null" if plugin is activated first time but no connection has been made yet to Buffer
        if (!$settings || empty($settings)) {
            return [
                'schedules' => [],
                'generals' => [],
            ];
        }

        return $settings;
    }

    /**
     * Return an array of connected networks
     */
    public function networks()
    {
        $nativeProfile = get_option($this->ecp_native_profiles);
        $networks = [];
        foreach ($nativeProfile as $key => $profiles) {
            foreach ($profiles as $key => $single_profile) {
                $networks[$single_profile->id] = [
                    'service' => $single_profile->service,
                    'formatted_service' => $single_profile->formatted_service . ' (' . $single_profile->formatted_username .')',
                    'avatar' => $single_profile->avatar ?? $single_profile->avatar_https,
                ];
            }
        }

        return $networks;
    }

     /**
     * Save the schedules for the native twitter.
     */
    public function save_schedules($schedules)
    {
        // if user can't edit option values, abort
        if (! current_user_can('manage_options')) {
            return false;
        }

        // $profiles = esc_sql($profiles);

        if (empty($schedules)) {
            return false;
        }

        $current_schedules = $this->load_schedules();

        if (false === $current_schedules) {
            $success = add_option($this->option_schedule_settings, $schedules);
        } else {
            $success = update_option($this->option_schedule_settings, $schedules);
        }

        return $success;
    }
}